package com.hw.mes.mapper;

import java.util.List;
import com.hw.mes.domain.MesSaleOrder;

/**
 * 销售订单信息Mapper接口
 * 
 * @author Yinq
 * @date 2024-02-19
 */
public interface MesSaleOrderMapper 
{
    /**
     * 查询销售订单信息
     * 
     * @param saleOrderId 销售订单信息主键
     * @return 销售订单信息
     */
    public MesSaleOrder selectMesSaleOrderBySaleOrderId(Long saleOrderId);

    /**
     * 查询销售订单信息列表
     * 
     * @param mesSaleOrder 销售订单信息
     * @return 销售订单信息集合
     */
    public List<MesSaleOrder> selectMesSaleOrderList(MesSaleOrder mesSaleOrder);

    /**
     * 新增销售订单信息
     * 
     * @param mesSaleOrder 销售订单信息
     * @return 结果
     */
    public int insertMesSaleOrder(MesSaleOrder mesSaleOrder);

    /**
     * 修改销售订单信息
     * 
     * @param mesSaleOrder 销售订单信息
     * @return 结果
     */
    public int updateMesSaleOrder(MesSaleOrder mesSaleOrder);

    /**
     * 删除销售订单信息
     * 
     * @param saleOrderId 销售订单信息主键
     * @return 结果
     */
    public int deleteMesSaleOrderBySaleOrderId(Long saleOrderId);

    /**
     * 批量删除销售订单信息
     * 
     * @param saleOrderIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMesSaleOrderBySaleOrderIds(Long[] saleOrderIds);
}
